@@ -6,7 +6,14 @@ use URI::URL();
 
 use base qw(Firefox::Marionette::Element);
 
-our $VERSION = '1.16';
+our $VERSION = '1.17';
+
+sub new {
+    my ( $class, $element ) = @_;
+    my $self = $element;
+    bless $self, $class;
+    return $self;
+}
 
 sub url {
     my ($self) = @_;
@@ -71,7 +78,7 @@ Firefox::Marionette::Link - Represents a link from the links method
 
 =head1 VERSION
 
-Version 1.16
+Version 1.17
 
 =head1 SYNOPSIS
 
@@ -105,6 +112,10 @@ returns the base url to which all links are relative.
 
 returns the name attribute, if any.
 
+=head2 new
+
+accepts an L<element|Firefox::Marionette::Element> as a parameter and returns a L<link|Firefox::Marionette::Link> object
+
 =head2 tag
 
 returns the tag (one of: "a", "area", "frame", "iframe" or "meta").
